==> vst3sdk-docs-3.7.14_build_55-1-any.pkg.tar.zst: usr/share/doc/vst3sdk-docs/vstgui/html/search/all_1.js <==
var searchData=
[
  ['1_0',['1',['../group__new__in__4__1.html',1,'Version 4.1'],['../page_news_and_changes.html#version4_1',1,'Version 4.1'],['../group__new__in__4__12__1.html',1,'Version 4.12.1'],['../page_news_and_changes.html#version4_12_1',1,'Version 4.12.1'],['../page_news_and_changes.html#code_changes_4_0_to_4_1',1,'VSTGUI 4.0 -&gt; VSTGUI 4.1']]],
  ['1_20vstgui_204_202_1',['VSTGUI 4.1 -&gt; VSTGUI 4.2',['../page_news_and_changes.html#code_changes_4_1_to_4_2',1,'']]],
  ['10_2',['10',['../group__new__in__4__10.html',1,'Version 4.10'],['../page_news_and_changes.html#version4_10',1,'Version 4.10'],['../page_news_and_changes.html#code_changes_4_9_to_4_10',1,'VSTGUI 4.9 -&gt; VSTGUI 4.10']]],
  ['10_20vstgui_204_2011_3',['VSTGUI 4.10 -&gt; VSTGUI 4.11',['../page_news_and_changes.html#code_changes_4_10_to_4_11',1,'']]],
  ['11_4',['11',['../group__new__in__4__11.html',1,'Version 4.11'],['../page_news_and_changes.html#version4_11',1,'Version 4.11'],['../page_news_and_changes.html#code_changes_4_10_to_4_11',1,'VSTGUI 4.10 -&gt; VSTGUI 4.11']]],
  ['11_20vstgui_204_2012_5',['VSTGUI 4.11 -&gt; VSTGUI 4.12',['../page_news_and_changes.html#code_changes_4_11_to_4_12',1,'']]],
  ['12_6',['12',['../group__new__in__4__12.html',1,'Version 4.12'],['../page_news_and_changes.html#version4_12',1,'Version 4.12'],['../page_news_and_changes.html#code_changes_4_11_to_4_12',1,'VSTGUI 4.11 -&gt; VSTGUI 4.12']]],
  ['12_201_7',['12 1',['../group__new__in__4__12__1.html',1,'Version 4.12.1'],['../page_news_and_changes.html#version4_12_1',1,'Version 4.12.1']]],
  ['12_202_8',['12 2',['../group__new__in__4__12__2.html',1,'Version 4.12.2'],['../page_news_and_changes.html#version4_12_2',1,'Version 4.12.2']]],
  ['12_20vstgui_204_2013_9',['VSTGUI 4.12 -&gt; VSTGUI 4.13',['../page_news_and_changes.html#code_changes_4_12_to_4_13',1,'']]],
  ['13_10',['13',['../page_news_and_changes.html#version4_13',1,'Version 4.13'],['../page_news_and_changes.html#code_changes_4_12_to_4_13',1,'VSTGUI 4.12 -&gt; VSTGUI 4.13']]],
  ['13_20vstgui_204_2014_11',['VSTGUI 4.13 -&gt; VSTGUI 4.14',['../page_news_and_changes.html#code_changes_4_13_to_4_14',1,'']]],
  ['14_12',['14',['../page_news_and_changes.html#version4_14',1,'Version 4.14'],['../page_news_and_changes.html#code_changes_4_13_to_4_14',1,'VSTGUI 4.13 -&gt; VSTGUI 4.14']]]
];

==> vst3sdk-docs-3.8.0_build_66-1-any.pkg.tar.zst: usr/share/doc/vst3sdk-docs/vstgui/html/search/all_1.js <==
var searchData=
[
  ['1_0',['1',['../group__new__in__4__1.html',1,'Version 4.1'],['../page_news_and_changes.html#version4_1',1,'Version 4.1'],['../group__new__in__4__12__1.html',1,'Version 4.12.1'],['../page_news_and_changes.html#version4_12_1',1,'Version 4.12.1'],['../page_news_and_changes.html#code_changes_4_0_to_4_1',1,'VSTGUI 4.0 -&gt; VSTGUI 4.1']]],
  ['1_20vstgui_204_202_1',['VSTGUI 4.1 -&gt; VSTGUI 4.2',['../page_news_and_changes.html#code_changes_4_1_to_4_2',1,'']]],
  ['10_2',['10',['../group__new__in__4__10.html',1,'Version 4.10'],['../page_news_and_changes.html#version4_10',1,'Version 4.10'],['../page_news_and_changes.html#code_changes_4_9_to_4_10',1,'VSTGUI 4.9 -&gt; VSTGUI 4.10']]],
  ['10_20vstgui_204_2011_3',['VSTGUI 4.10 -&gt; VSTGUI 4.11',['../page_news_and_changes.html#code_changes_4_10_to_4_11',1,'']]],
  ['11_4',['11',['../group__new__in__4__11.html',1,'Version 4.11'],['../page_news_and_changes.html#version4_11',1,'Version 4.11'],['../page_news_and_changes.html#code_changes_4_10_to_4_11',1,'VSTGUI 4.10 -&gt; VSTGUI 4.11']]],
  ['11_20vstgui_204_2012_5',['VSTGUI 4.11 -&gt; VSTGUI 4.12',['../page_news_and_changes.html#code_changes_4_11_to_4_12',1,'']]],
  ['12_6',['12',['../group__new__in__4__12.html',1,'Version 4.12'],['../page_news_and_changes.html#version4_12',1,'Version 4.12'],['../page_news_and_changes.html#code_changes_4_11_to_4_12',1,'VSTGUI 4.11 -&gt; VSTGUI 4.12']]],
  ['12_201_7',['12 1',['../group__new__in__4__12__1.html',1,'Version 4.12.1'],['../page_news_and_changes.html#version4_12_1',1,'Version 4.12.1']]],
  ['12_202_8',['12 2',['../group__new__in__4__12__2.html',1,'Version 4.12.2'],['../page_news_and_changes.html#version4_12_2',1,'Version 4.12.2']]],
  ['12_20vstgui_204_2013_9',['VSTGUI 4.12 -&gt; VSTGUI 4.13',['../page_news_and_changes.html#code_changes_4_12_to_4_13',1,'']]],
  ['13_10',['13',['../page_news_and_changes.html#version4_13',1,'Version 4.13'],['../page_news_and_changes.html#code_changes_4_12_to_4_13',1,'VSTGUI 4.12 -&gt; VSTGUI 4.13']]],
  ['13_20vstgui_204_2014_11',['VSTGUI 4.13 -&gt; VSTGUI 4.14',['../page_news_and_changes.html#code_changes_4_13_to_4_14',1,'']]],
  ['14_12',['14',['../page_news_and_changes.html#version4_14',1,'Version 4.14'],['../page_news_and_changes.html#code_changes_4_13_to_4_14',1,'VSTGUI 4.13 -&gt; VSTGUI 4.14']]],
  ['15_13',['15',['../group__new__in__4__15.html',1,'Version 4.15'],['../page_news_and_changes.html#version4_15',1,'Version 4.15']]]
];
